<?php

/*
Plugin Name: Buy Sell Ads Wordpress Plugin
Plugin URI: http://adsplugin.fanpagesmarket.com
Description: Plugin to buying and selling advertising on your site. Earn on Wordpress!
Author: Socialeo Team
Author URI: http://codecanyon.net/user/socialeo
Version: 2.7.1
License: GPL2
*/

// Require files
require_once 'inc/bsa-menu.php';
require_once 'lib/functions.php';
require_once 'lib/BSA_Payments.php';
require_once 'lib/BSA_Model.php';
require_once 'lib/BSA_Request.php';

// Define variables
// items
define('PLUGIN_MIN_ITEMS', 3); // Minimum items for plugin
define('WIDGET_MIN_ITEMS', 1); // Minimum items for widget
define('PLUGIN_MAX_ITEMS', 24); // Maximum items for plugin
define('WIDGET_MAX_ITEMS', 12); // Maximum items for widget
// characters
define('MAX_TITLE_INPUT', 40); // Maximum characters for title
define('MAX_DESC_INPUT', 80); // Maximum characters for description

class BuySellAdsPlugin
{
	private static $plugin_id = 'bsa_plugin';
	private $plugin_version = '2.7.1';

	private $model;

	function __construct() {
		$this->model = new BSA_Model();
		register_activation_hook(__FILE__, array($this, 'onActivate'));
		register_uninstall_hook(__FILE__, array('BuySellAdsPlugin', 'onUninstall'));
	}

	static function onUninstall() {
		$model = new BSA_Model();
		$model->dropTable();

		$ver_opt = static::$plugin_id.'_version';
		delete_option($ver_opt);
	}

	function onActivate() {
		$opt = static::$plugin_id;
		$opt_trans = static::$plugin_id.'_trans';
		$ver_opt = static::$plugin_id.'_version';
		$installed_version = get_option($ver_opt, NULL);

		if($installed_version == NULL) {

			$this->model->createDbTable();

			// plugin options
			update_option($ver_opt, $this->plugin_version);
			update_option($opt.'_paypal', 'example_paypal@gmail.com');
			update_option($opt.'_price', 1.00);
			update_option($opt.'_thumb_size', 100);
			update_option($opt.'_thumb_w', 200);
			update_option($opt.'_thumb_h', 200);
			update_option($opt.'_contract_first', 30);
			update_option($opt.'_contract_second', 60);
			update_option($opt.'_contract_third', 90);
			update_option($opt.'_discount_second', 10);
			update_option($opt.'_discount_third', 25);
			update_option($opt.'_currency_symbol', '$');
			update_option($opt.'_symbol_position', 'before');
			update_option($opt.'_currency_code', 'USD');
			update_option($opt.'_style', 'default');
			update_option($opt.'_max_items', 12);
			update_option($opt.'_col_per_row', 3);
			update_option($opt.'_wgt_max_items', 6);

			// translations
			update_option($opt_trans.'_name', 'Featured section');
			update_option($opt_trans.'_new_ad', 'create ad');
			// form left
			update_option($opt_trans.'_form_left_header', 'Create new ad');
			update_option($opt_trans.'_form_left_email', 'Your email');
			update_option($opt_trans.'_form_left_eg_email', 'example@gmail.com');
			update_option($opt_trans.'_form_left_title', 'Ad title');
			update_option($opt_trans.'_form_left_eg_title', 'example title');
			update_option($opt_trans.'_form_left_desc', 'Ad description');
			update_option($opt_trans.'_form_left_eg_desc', 'example description');
			update_option($opt_trans.'_form_left_url', 'Ad URL');
			update_option($opt_trans.'_form_left_eg_url', 'http://example.com');
			update_option($opt_trans.'_form_left_thumb', 'Thumbnail: png, jpg, gif (size: 200 x 200px, 100kb)');
			// form right
			update_option($opt_trans.'_form_right_header', 'How long you want display ad?');
			update_option($opt_trans.'_form_right_1_week', '1 week');
			update_option($opt_trans.'_form_right_2_weeks', '2 weeks');
			update_option($opt_trans.'_form_right_1_month', '1 month');
			update_option($opt_trans.'_form_right_2_months', '2 months');
			update_option($opt_trans.'_form_right_3_months', '3 months');
			update_option($opt_trans.'_form_right_6_months', '6 months');
			update_option($opt_trans.'_form_right_12_months', '12 months');
			update_option($opt_trans.'_form_right_button_pay', 'Pay via PayPal');
			// alerts
			// success
			update_option($opt_trans.'_alert_success', 'Success!');
			update_option($opt_trans.'_form_success', 'Correctly added! You will be redirected to PayPal');
			update_option($opt_trans.'_payment_success', 'Correctly payment.');
			// failed
			update_option($opt_trans.'_alert_failed', 'Error!');
			update_option($opt_trans.'_form_invalid_params', 'Invalid params for payment!');
			update_option($opt_trans.'_form_too_high', 'Image too high!');
			update_option($opt_trans.'_form_img_invalid', 'Image invalid!');
			update_option($opt_trans.'_form_empty', 'All fields required!');
			update_option($opt_trans.'_payment_failed', 'Payment failed. Please try again.');
			// stats section
			update_option($opt_trans.'_stats_header', 'Statistics');
			update_option($opt_trans.'_stats_views', 'Views');
			update_option($opt_trans.'_stats_clicks', 'Clicks');
			update_option($opt_trans.'_stats_ctr', 'CTR');
			// confirmation email
			update_option($opt_trans.'_email_sender', 'Sender name');
			update_option($opt_trans.'_email_address', 'example@example.com');
			update_option($opt_trans.'_email_subject', 'Advertising was correctly added');
			update_option($opt_trans.'_email_message', 'Your advertise is live!

You can follow statistics by url:
[STATS_URL]

Regards,
Your Signature
');

		} else {

			switch(version_compare($installed_version, $this->plugin_version)) {

				case 0;
					// if the same
					//update_option($ver_opt, $this->plugin_version);
					break;

				case 1;
					// if newer
					//update_option($ver_opt, $this->plugin_version);
					break;

				case -1;
					// if older
					//update_option($ver_opt, $this->plugin_version);
					break;
			}
		}
	}
}

function BSA_add_stylesheet_and_script()
{
	wp_register_style('buy_sell_ads_stylesheet', plugins_url('frontend/css/'.get_option('bsa_plugin_style').'.css', __FILE__));
	wp_enqueue_style('buy_sell_ads_stylesheet');
	wp_register_style('buy_sell_ads_animate_stylesheet', plugins_url('frontend/css/asset/animate.css', __FILE__));
	wp_enqueue_style('buy_sell_ads_animate_stylesheet');
	wp_register_script('buy_sell_ads_js_script', plugins_url('frontend/js/bsa-script.js', __FILE__), array('jquery','media-upload','thickbox'));
	wp_enqueue_script('buy_sell_ads_js_script');
}
add_action('wp_enqueue_scripts', 'BSA_add_stylesheet_and_script');

function getColorOpt($name, $type) {
	$get_opt = 'bsa_plugin_';
	$get_color = get_option($get_opt.$name);
	if ( $get_color ) {
		if ( $type == 'bg' ) {
			return 'background-color: '.$get_color.' !important;';
		} elseif ( $type == 'c' ) {
			return 'color: '.$get_color.' !important;';
		} elseif ( $type == 'a' ) {
			if ( $get_color ) {
				return 'color: '.$get_color.' !important;';
			} else {
				return 'color: inherit;';
			}
		} elseif ( $type == 'a:h' ) {
			if ( $get_color ) {
				return 'color: '.$get_color.' !important;';
			} else {
				return 'color: inherit;';
			}
		} elseif ( $type == 'bc' ) {
			return 'border-color: '.$get_color.' !important;';
		}
	} else {
		return NULL;
	}
}

function BSA_add_custom_stylesheet()
{
	echo "
	<style>
		/* Custom BSA Styles */

		/* main */
		.bsaHeadTitle { ".getColorOpt('c_title', 'c')." }
		.bsaBgColor { ".getColorOpt('bg_color', 'bg')." }
		.bsaHeadContainer a { ".getColorOpt('c_link', 'a')." }
		.bsaHeadContainer a:hover,
		.bsaHeadContainer a:focus { ".getColorOpt('c_link_hover', 'a:h')." }

		/* form */
		.bsaBgFormInner { ".getColorOpt('bg_form', 'bg')." ".getColorOpt('c_form', 'c')." }
		.bsaBgInput { ".getColorOpt('bg_form_input', 'bg')." ".getColorOpt('c_form_input', 'c')." }
		.bsaDiscount { ".getColorOpt('c_discount', 'c')." }
		.bsaSubmit,
		.bsaSubmit:hover,
		.bsaSubmit:active { ".getColorOpt('c_submit', 'c')." }
		.bsaSubmit span { ".getColorOpt('bg_submit', 'bg')." ".getColorOpt('bc_submit', 'bc')." }

		/* item */
		.bsaBgItems { ".getColorOpt('bg_item', 'bg')." ".getColorOpt('c_item', 'c')." }
		.bsaInnerUrl { ".getColorOpt('c_item_url', 'c')." }
		.bsaItemStats { ".getColorOpt('bg_item_stats', 'bg')." }

		/* allerts */
		.bsaAlert,
		.bsaAlert > a,
		.bsaAlert > a:hover,
		.bsaAlert > a:focus { ".getColorOpt('c_alert_link', 'a')." }
		.bsaAlertSuccess { ".getColorOpt('bg_alert_success', 'bg')." }
		.bsaAlertFailed { ".getColorOpt('bg_alert_failed', 'bg')." }

		/* paypal */
		#bsaPayPalRedirect { ".getColorOpt('c_title', 'c')." }
	</style>
	";
}
add_action('wp_enqueue_scripts', 'BSA_add_custom_stylesheet');

function BSA_add_admin_stylesheet() {
	wp_register_style('bsa_admin_theme', plugins_url('frontend/css/asset/admin.css', __FILE__));
	wp_enqueue_style('bsa_admin_theme');
}
add_action('admin_enqueue_scripts', 'BSA_add_admin_stylesheet');

function BSA_load_color_picker() {
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_script( 'wp-color-picker' );
}
add_action( 'admin_enqueue_scripts', 'BSA_load_color_picker' );

class WidgetBuySellAdsInit extends WP_Widget
{
	public function __construct() {
		parent::__construct('buy_sell_ads_wgt', 'Buy Sell Ads Wordpress Plugin', array(
			'description' => 'Plugin to buying and selling advertising on Wordpress site.',
		));
	}

	public function getItemPrice($months, $discount)
	{
		$weeks = '';
		if (get_option('bsa_plugin_contract_first') == 7) {
			$weeks = 4;
		} elseif (get_option('bsa_plugin_contract_first') == 14) {
			$weeks = 2;
		} elseif (get_option('bsa_plugin_contract_first') == 30) {
			$weeks = 1;
		}
		$price = number_format((get_option('bsa_plugin_price') * $weeks), 2, '.', '');
		$price = number_format(($price * $months), 2, '.', '');
		if ( get_option($discount) != 0 && get_option($discount) != NULL ) {
			$priceDiscount = get_option($discount);
		} else {
			$priceDiscount = NULL;
		}
		if ( $priceDiscount != NULL ) {
			$priceDiscount = $price * $priceDiscount / 100;
		} else {
			$priceDiscount = 0;
		}
		$cost = number_format($price - $priceDiscount, 2, '.', '');

		if (get_option('bsa_plugin_symbol_position') == 'before') {
			echo '<span class="bsaPrice">'.get_option('bsa_plugin_currency_symbol').$cost.'</span>';
		} elseif (get_option('bsa_plugin_symbol_position') == 'after') {
			echo '<span class="bsaPrice">'.$cost.get_option('bsa_plugin_currency_symbol').'</span>';
		}
		if ( $discount != NULL ) {
			echo '<span class="bsaDiscount">(-'.get_option($discount).'%)</span>';
		} else {
			echo '';
		}
	}

	public function widget( $args, $instance ) {
		$model = new BSA_Model();
		$getPosts = $model->getActiveFanpages(get_option('bsa_plugin_wgt_max_items'));
		$countPosts = count($getPosts);
		$maxItems = get_option('bsa_plugin_wgt_max_items');
		if ( isset($_POST['submitWidget']) ) {
			$getForm = $model->getForm();
		} else {
			$getForm = '';
		}
		if (isset($_GET['bsa_payment']) && $_GET['bsa_payment'] == 'notify') {
			$model->notifyAction();
		}
		$lastUrl = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
		$_SESSION['bsa_last_url'] = $lastUrl;
		$bsaActionType = 'Widget';
		$bsaId = 'bsa_plugin';
		$bsaTrans = $bsaId.'_trans';
		$model->bsaCounter();
		require_once 'inc/bsa-wgt.php';
	}

	public function form( $instance ) {
		// outputs the options form on admin
	}

	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
	}
}
add_action( 'widgets_init', function(){
	register_widget( 'WidgetBuySellAdsInit' );
});

$BuySellAdsPlugin = new BuySellAdsPlugin();

?>