<?php

class BSA_Model {

	protected $wpdb;
	private $table_name = 'bsa_plugin';

	public function __construct() {
		global $wpdb;
		$this->wpdb = $wpdb;
	}

	public function getTableName() {
		return $this->wpdb->prefix.$this->table_name;
	}

	public function createDbTable() {

		$table_name = $this->getTableName();
		$MAX_TITLE_INPUT = MAX_TITLE_INPUT;
		$MAX_DESC_INPUT = MAX_DESC_INPUT;

		$sql = "
			CREATE TABLE IF NOT EXISTS {$table_name} (
				id INT (10) NOT NULL AUTO_INCREMENT,
				buyer_email VARCHAR (255) NOT NULL,
				title VARCHAR ({$MAX_TITLE_INPUT}) NOT NULL,
				description VARCHAR ({$MAX_DESC_INPUT}) NOT NULL,
				url VARCHAR (255) NOT NULL,
				img VARCHAR (255) NOT NULL,
				expiration_time INT (10) NOT NULL,
				cost FLOAT (10,2) NOT NULL,
				views BIGINT (20) NOT NULL DEFAULT '0',
				clicks INT (10) NOT NULL DEFAULT '0',
				paid TINYINT (1),
				p_time INT (10),
				p_data TEXT,
				p_error VARCHAR (50),
				blocked TINYINT (1),
				PRIMARY KEY(id)
			)ENGINE=InnoBD DEFAULT CHARSET=utf8
			";

		require_once ABSPATH.'wp-admin/includes/upgrade.php';
		dbDelta($sql, TRUE);
	}

	public function addNewAd($id = NULL, $email, $title, $desc, $url, $img, $time) {
		$this->addNewAdDB($id = NULL, $email, $title, $desc, $url, $img, $time);
	}

	protected function addNewAdDB($id = NULL, $email, $title, $desc, $url, $img, $time) {
		$this->wpdb->insert(
			$this->getTableName(),
			array(
				'id' => $id,
				'buyer_email' => $email,
				'title' => $title,
				'description' => $desc,
				'url' => $url,
				'img' => $img,
				'expiration_time' => $time,
				'cost' => 0,
				'paid' => 1,
				'blocked' => 0
			),
			array()
		);
	}

	public function updateAd($id, $email, $title, $desc, $url, $img, $time) {
		$this->updateAdDB($id, $email, $title, $desc, $url, $img, $time);
	}

	protected function updateAdDB($id, $email, $title, $desc, $url, $img = NULL, $time = NULL) {
		$this->wpdb->update(
			$this->getTableName(),
			array(
				'buyer_email' => $email,
				'title' => $title,
				'description' => $desc,
				'url' => $url
			),
			array( 'id' => $id ),
			array(
				'%s',
				'%s',
				'%s',
				'%s'
			),
			array( '%s' )
		);
		if ( isset($img) && $img != NULL ) {
			$this->wpdb->update(
				$this->getTableName(),
				array(
					'img' => $img
				),
				array( 'id' => $id ),
				array(
					'%s'
				),
				array( '%s' )
			);
		}
		if ( $time != NULL ) {
			$this->wpdb->update(
				$this->getTableName(),
				array(
					'expiration_time' => $time
				),
				array( 'id' => $id ),
				array(
					'%s'
				),
				array( '%s' )
			);
		}
	}

	public function getAdmAd()
	{
		$table_name = $this->getTableName();
		$sql = "SELECT * FROM {$table_name} WHERE id = {$_GET['ad_id']} LIMIT 1";
		return $this->wpdb->get_row($sql, ARRAY_A);
	}

	protected function getCost($months, $discount)
	{
		$discount = 'bsa_plugin_discount_'.$discount;
		$weeks = '';
		if (get_option('bsa_plugin_contract_first') == 7) {
			$weeks = 4;
		} elseif (get_option('bsa_plugin_contract_first') == 14) {
			$weeks = 2;
		} elseif (get_option('bsa_plugin_contract_first') == 30) {
			$weeks = 1;
		}

		$price = number_format((get_option('bsa_plugin_price') * $weeks), 2, '.', '');
		$price = number_format(($price * $months), 2, '.', '');

		if ( get_option($discount) != 0 && get_option($discount) != NULL ) {
			$priceDiscount = get_option($discount);
		} else {
			$priceDiscount = NULL;
		}
		if ( $priceDiscount != NULL ) {
			$priceDiscount = $price * $priceDiscount / 100;
		} else {
			$priceDiscount = 0;
		}
		$cost = number_format($price - $priceDiscount, 2, '.', '');
		return $cost;
	}

	public $sendPayment;
	public function getForm()
	{
		if (isset($_POST) && isset($_POST['actionForm'])) {

			if ($_POST['bsa_email'] != '' && $_POST['bsa_title'] != ''  && $_POST['bsa_desc']  && $_POST['bsa_url'] != '') {

				if ($_FILES["bsa_file"]) {
					$allowedExts = array("gif", "jpeg", "jpg", "png");
					$temp = explode(".", $_FILES["bsa_file"]["name"]);
					$extension = end($temp);

					if ((($_FILES["bsa_file"]["type"] == "image/gif")
							|| ($_FILES["bsa_file"]["type"] == "image/jpeg")
							|| ($_FILES["bsa_file"]["type"] == "image/jpg")
							|| ($_FILES["bsa_file"]["type"] == "image/pjpeg")
							|| ($_FILES["bsa_file"]["type"] == "image/x-png")
							|| ($_FILES["bsa_file"]["type"] == "image/png"))
						&& $_FILES["bsa_file"]["error"] == 0
						&& in_array($extension, $allowedExts)) {

						$get_expiration = explode('_', $_POST['expiration_time']);
						$expiration_time = time() + ($get_expiration[0] * 24 * 60 * 60);

						$fileName = $expiration_time.'-'.$_FILES["bsa_file"]["name"];
						$path     = ABSPATH.'wp-content/plugins/bsa-socialeo/thumbs/'.$fileName;
						$thumbLoc = $_FILES["bsa_file"]["tmp_name"];
						list($width, $height) = getimagesize($thumbLoc);

						if ( get_option('bsa_plugin_thumb_size') ) {
							$maxSize = get_option('bsa_plugin_thumb_size');
						} else {
							$maxSize = 100;
						}
						if ( get_option('bsa_plugin_thumb_w') ) {
							$maxWidth = get_option('bsa_plugin_thumb_w');
						} else {
							$maxWidth = 200;
						}
						if ( get_option('bsa_plugin_thumb_h') ) {
							$maxHeight = get_option('bsa_plugin_thumb_h');
						} else {
							$maxHeight = 200;
						}

						if (($_FILES["bsa_file"]["size"] > $maxSize * 1024) OR $width > $maxWidth OR $height > $maxHeight) {

							if ($_POST['actionForm'] == 'Plugin') {
								return "invalidPluginSizeFile"; // file was invalid
							} elseif ($_POST['actionForm'] == 'Widget') {
								return "invalidWidgetSizeFile"; // file was invalid
							}

						} else {

							move_uploaded_file($thumbLoc, $path);

							$cost = NULL;
							if ($get_expiration[0] == 7 || $get_expiration[0] == 14 || $get_expiration[0] == 30 && $get_expiration[1] == 'first') {

								$cost = number_format((get_option('bsa_plugin_price') * 1), 2, '.', '');

							} elseif ($get_expiration[0] == 14 && $get_expiration[1] == 'second') {

								$cost = $this->getCost(0.5, $get_expiration[1]);

							} elseif ($get_expiration[0] == 30 && $get_expiration[1] == 'second') {

								$cost = $this->getCost(1, $get_expiration[1]);

							} elseif ($get_expiration[0] == 60 && $get_expiration[1] == 'second') {

								$cost = $this->getCost(2, $get_expiration[1]);

							} elseif ($get_expiration[0] == 90 && $get_expiration[1] == 'second') {

								$cost = $this->getCost(3, $get_expiration[1]);

							} elseif ($get_expiration[0] == 30 && $get_expiration[1] == 'third') {

								$cost = $this->getCost(1, $get_expiration[1]);

							} elseif ($get_expiration[0] == 90 && $get_expiration[1] == 'third') {

								$cost = $this->getCost(3, $get_expiration[1]);

							} elseif ($get_expiration[0] == 180 && $get_expiration[1] == 'third') {

								$cost = $this->getCost(6, $get_expiration[1]);

							} elseif ($get_expiration[0] == 365 && $get_expiration[1] == 'third') {

								$cost = $this->getCost(12, $get_expiration[1]);

							}

							if ($cost != NULL) {

								$this->wpdb->insert(
									$this->getTableName(),
									array(
										'id' => NULL,
										'buyer_email' => $_POST['bsa_email'],
										'title' => $_POST['bsa_title'],
										'description' => $_POST['bsa_desc'],
										'url' => $_POST['bsa_url'],
										'img' => $fileName,
										'expiration_time' => $expiration_time,
										'cost' => $cost
									),
									array()
								);

								$paymentModel = new BSA_Payments();
								$this->sendPayment =  $paymentModel->sendPayment($this->wpdb->insert_id, $_POST['bsa_email'], $cost, $_POST['actionForm']);

							} else {

								if($_POST['actionForm'] == 'Plugin') {
									return "invalidPluginParams"; // payments params invalid
								} elseif ($_POST['actionForm'] == 'Widget') {
									return "invalidWidgetParams"; // payments params invalid
								}
							}
						}

					} else {

						if($_POST['actionForm'] == 'Plugin') {
							return "invalidPluginFile"; // file was invalid
						} elseif ($_POST['actionForm'] == 'Widget') {
							return "invalidWidgetFile"; // file was invalid
						}
					}
				} else {

					if ($_POST['actionForm'] == 'Plugin') {
						return "invalidPluginFile"; // file was invalid
					} elseif ($_POST['actionForm'] == 'Widget') {
						return "invalidWidgetFile"; // file was invalid
					}
				}

				if($_POST['actionForm'] == 'Plugin') {
					return 'successPluginAdded'; // success added to DB
				} elseif ($_POST['actionForm'] == 'Widget') {
					return 'successWidgetAdded'; // success added to DB
				}

			} else {

				if($_POST['actionForm'] == 'Plugin') {
					return "emptyPluginForm"; // error, form empty
				} elseif ($_POST['actionForm'] == 'Widget') {
					return "emptyWidgetForm"; // error, form empty
				}
			}
		} else {

			return "showForm"; // display form
		}

		return "showForm"; // display form
	}

	public function notifyAction()
	{
		if(empty($_POST) && !isset($_POST['bsaAction']))
			return;

		$paymentId = $_POST['item_number'];
		$payment_crc = $_POST['custom'];
		try
		{
			$timestamp = time();
			$data = json_encode($_POST);

			$this->wpdb->update(
				$this->getTableName(),
				array(
					'p_time' => $timestamp,
					'p_data' => $data
				),
				array( 'id' => $paymentId ),
				array(
					'%d',
					'%s'
				),
				array( '%s' )
			);

			if($payment_crc != md5($_POST['item_number'].number_format($_POST['mc_gross'], 2, '.', '')))
				throw new \Exception('price changed');

			if($_POST['payment_status'] == 'Pending')
				throw new \Exception('payment is pending');

			if($_POST['payment_status'] == 'Denied')
				throw new \Exception('payment is denied');
		}
		catch(\Exception $e)
		{
			$error = $e->getMessage();
		}

		if (isset($error)) {
			$this->wpdb->update(
				$this->getTableName(),
				array(
					'p_error' => $error,
					'blocked' => 1
				),
				array( 'id' => $paymentId ),
				array(
					'%s',
					'%d'
				),
				array( '%s' )
			);
		}

		if ($_POST['payment_status'] == 'Completed' && !isset($error))
		{
			$this->wpdb->update(
				$this->getTableName(),
				array(
					'paid' => 1,
					'blocked' => 0
				),
				array( 'id' => $paymentId ),
				array(
					'%d',
					'%d'
				),
				array( '%d' )
			);
		}

		if (isset($error)) {
			echo FALSE;
		} else {
			$paymentEmail = $_POST['item_name'];
			$sender = get_option('bsa_plugin_trans_email_sender');
			$email = get_option('bsa_plugin_trans_email_address');
			$subject = get_option('bsa_plugin_trans_email_subject');
			$message = get_option('bsa_plugin_trans_email_message');
			$search = '[STATS_URL]';
			$replace = "http://".str_replace('bsa_payment=notify', '', $_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'])."bsa_stats=1&bsa_email=".str_replace('@', '%40', $paymentEmail)."&bsa_id=".$paymentId."#bsaStats\r\n";
			$message = str_replace($search, $replace, $message);
			$headers = 'From: '.$sender.' <'.$email.'>' . "\r\n";
			wp_mail($paymentEmail, $subject, $message, $headers );
			echo TRUE;
		}
	}

	protected $orderId;
	protected function adminAction()
	{
		if (isset($_POST) && isset($_POST['bsaAction']) && isset($_POST['submit']) && isset($_POST['orderId'])) {

			$this->orderId = $_POST['orderId'];

			if ($_POST['bsaAction'] == 'block') {

				$sql = $this->wpdb->update(
					$this->getTableName(),
					array(
						'blocked' => 1
					),
					array( 'id' => $this->orderId ),
					array(
						'%d'
					),
					array( '%d' )
				);

				if ($sql > 0) {

					$_SESSION['validationStatus'] = 'blocked';
					return 'blocked';
				} else {
					return NULL;
				}

			} elseif ($_POST['bsaAction'] == 'unblock') {

				$sql = $this->wpdb->update(
					$this->getTableName(),
					array(
						'blocked' => 0
					),
					array( 'id' => $this->orderId ),
					array(
						'%d'
					),
					array( '%d' )
				);

				if ($sql > 0) {

					$_SESSION['validationStatus'] = 'unblocked';
					return 'unblocked';
				} else {
					return NULL;
				}

			} elseif ($_POST['bsaAction'] == 'paid') {

				$timestamp = time();

				$sql = $this->wpdb->update(
					$this->getTableName(),
					array(
						'paid' => 1,
						'p_time' => $timestamp,
						'blocked' => 0
					),
					array( 'id' => $this->orderId ),
					array(
						'%d',
						'%d',
						'%d'
					),
					array( '%d' )
				);

				if ($sql > 0) {

					$_SESSION['validationStatus'] = 'paid';
					return 'paid';
				} else {
					return NULL;
				}
			}
		}
	}

	public function getAdminAction()
	{
		return $this->adminAction();
	}

	private $validationStatus;
	private function getValidationStatus()
	{
		if(is_null($this->validationStatus))
		{
			$this->validationStatus = '';

			if(isset($_SESSION['validationStatus']))
			{
				$this->validationStatus = $_SESSION['validationStatus'];

				unset($_SESSION['validationStatus']);
			}
		}

		return $this->validationStatus;
	}

	public function validationBlocked()
	{
		return $this->getValidationStatus() == 'blocked';
	}

	public function validationUnblocked()
	{
		return $this->getValidationStatus() == 'unblocked';
	}

	public function validationPaid()
	{
		return $this->getValidationStatus() == 'paid';
	}

	public function getActiveFanpages($limit = PLUGIN_MAX_ITEMS)
	{
		$table_name = $this->getTableName();
		$currently_time = time();

		$sql = "SELECT * FROM {$table_name} WHERE expiration_time >= {$currently_time} AND paid = 1 AND blocked != 1 ORDER BY expiration_time LIMIT {$limit}";
		return $this->wpdb->get_results($sql);
	}

	public function getNotPaidFanpages()
	{
		$table_name = $this->getTableName();
		$currently_time = time();

		$sql = "SELECT * FROM {$table_name} WHERE expiration_time >= {$currently_time} AND paid IS NULL AND blocked IS NULL ORDER BY id DESC LIMIT 20";
		return $this->wpdb->get_results($sql);
	}

	public function getArchiveFanpages()
	{
		$table_name = $this->getTableName();
		$currently_time = time();

		$sql = "SELECT * FROM {$table_name} WHERE expiration_time < {$currently_time} ORDER BY id LIMIT 10";
		return $this->wpdb->get_results($sql);
	}

	public function getBlockedFanpages()
	{
		$table_name = $this->getTableName();

		$sql = "SELECT * FROM {$table_name} WHERE blocked = 1 ORDER BY id LIMIT 10";
		return $this->wpdb->get_results($sql);
	}

	function dropTable()
	{
		$table_name = $this->getTableName();

		$sql = "DROP TABLE {$table_name}";
		return $this->wpdb->query($sql);
	}

	private $bsa_stats;
	private $bsa_email;
	private $bsa_id;
	private function bsaStatsValidation() {
		if ( isset( $_GET['bsa_stats'] ) && $_GET['bsa_stats'] == 1 && isset( $_GET['bsa_email'] ) && isset( $_GET['bsa_id'] ) ) {
			$table_name = $this->getTableName();
			$this->bsa_stats = $_GET['bsa_stats'];
			$this->bsa_email = $_GET['bsa_email'];
			$this->bsa_id = $_GET['bsa_id'];
			$sql = "SELECT buyer_email FROM {$table_name} WHERE id = {$this->bsa_id} LIMIT 1";
			$resEmail = $this->wpdb->get_row($sql, ARRAY_A);
			if ($resEmail['buyer_email'] == $this->bsa_email) {
				return TRUE;
			} else {
				return FALSE;
			}
		} else {
			return FALSE;
		}
	}

	public function bsaStats() {

		$table_name = $this->getTableName();
		if ( $this->bsaStatsValidation() == TRUE ) {
			$sql = "SELECT id, title, img, views, clicks, expiration_time FROM {$table_name} WHERE id = {$this->bsa_id} LIMIT 1";
			return $this->wpdb->get_row($sql, ARRAY_A);
		} else {
			return FALSE;
		}
	}

	function bsaCounter() {

		$table_name = $this->getTableName();
		if ( isset( $_GET['bsa_url'] ) && isset( $_GET['bsa_id'] ) ) {
			$id = $_GET['bsa_id'];
			$url = $_GET['bsa_url'];
			$sql = "UPDATE {$table_name} SET clicks = clicks + 1 WHERE paid = 1 AND blocked = 0 AND id = {$id}";
			$this->wpdb->query($sql);
			return 'http://'.$url;
		} else {
			$sql = "UPDATE {$table_name} SET views = views + 1 WHERE paid = 1 AND blocked = 0";
			$this->wpdb->query($sql);
			return TRUE;
		}
	}
}

function bsa_wp_redirect() {
	if ( isset( $_GET['bsa_url'] ) && isset( $_GET['bsa_id'] ) ) {
		$model = new BSA_Model();
		wp_redirect( $model->bsaCounter() );
		exit;
	}
}
add_action( 'wp', 'bsa_wp_redirect' );